@@ -268,7 +268,8 @@ def is_associative(value):
 
 
 def is_blank(text):
-    r"""Checks if `text` contains only whitespace characters.
+    r"""
+    Checks if `text` contains only whitespace characters.
 
     Args:
         text (str): String to test.
@@ -535,9 +536,9 @@ def is_equal_with(value, other, customizer):
         and len(value) == len(other)
     ):
         # Walk a/b to determine equality using customizer.
-        for key, value in iterator(value):
+        for key, val in iterator(value):
             if pyd.has(other, key):
-                equal = is_equal_with(value, other[key], customizer)
+                equal = is_equal_with(val, other[key], customizer)
             else:
                 equal = False
 
