@@ -9,12 +9,6 @@ import pydash as _
 parametrize = pytest.mark.parametrize
 
 
-@pytest.fixture
-def mocked_sleep():
-    with mock.patch("time.sleep") as mocked:
-        yield mocked
-
-
 @parametrize(
     "case,expected",
     [
@@ -184,13 +178,10 @@ def test_debounce_max_wait():
     "func,wait,args,kwargs,expected",
     [(lambda a, b, c: (a, b, c), 250, (1, 2), {"c": 3}, (1, 2, 3))],
 )
-def test_delay(func, wait, args, kwargs, expected):
-    start = time.time() * 1000
+def test_delay(mock_sleep, func, wait, args, kwargs, expected):
     result = _.delay(func, wait, *args, **kwargs)
-    stop = time.time() * 1000
-
-    assert (wait - 10) <= (stop - start) <= (wait + 10)
     assert result == expected
+    assert mock_sleep.call_args_list == [mock.call(pytest.approx(wait / 1000.0))]
 
 
 @parametrize(
@@ -289,8 +280,8 @@ def test_once(case, arglist, expected):
 @parametrize(
     "func,transforms,args,expected",
     [
-        (lambda a, b: [a, b], [lambda x: x ** 2, lambda x: x * 2], (5, 10), [25, 20]),
-        (lambda a, b: [a, b], ([lambda x: x ** 2, lambda x: x * 2],), (5, 10), [25, 20]),
+        (lambda a, b: [a, b], [lambda x: x**2, lambda x: x * 2], (5, 10), [25, 20]),
+        (lambda a, b: [a, b], ([lambda x: x**2, lambda x: x * 2],), (5, 10), [25, 20]),
     ],
 )
 def test_over_args(func, transforms, args, expected):
